1.1.2 / 2016-05-05
------------------

- Fixed typo in RGBA blur math equations (regression from 1.1.0),
  thanks to @tonykwok.


1.1.1 / 2015-11-10
------------------

- Fixed line buffer size for mono blur when vertical images used.


1.1.0 / 2015-11-05
------------------

- Changed interpolation fn to one from Intel's whitepaper.


1.0.1 / 2015-11-04
------------------

- Maintenance: general cleanup, demo improvements.


1.0.0 / 2015-11-02
------------------

- First release.
